package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcCheckMapper;
import com.ruoyi.oa.domain.CmcCheck;
import com.ruoyi.oa.service.ICmcCheckService;

/**
 * cmc项目核算Service业务层处理
 * 
 * @author cmc
 * @date 2025-05-13
 */
@Service
public class CmcCheckServiceImpl implements ICmcCheckService 
{
    @Autowired
    private CmcCheckMapper cmcCheckMapper;

    /**
     * 查询cmc项目核算
     * 
     * @param checkId cmc项目核算主键
     * @return cmc项目核算
     */
    @Override
    public CmcCheck selectCmcCheckByCheckId(String checkId)
    {
        return cmcCheckMapper.selectCmcCheckByCheckId(checkId);
    }

    /**
     * 查询cmc项目核算列表
     * 
     * @param cmcCheck cmc项目核算
     * @return cmc项目核算
     */
    @Override
    public List<CmcCheck> selectCmcCheckList(CmcCheck cmcCheck)
    {
        return cmcCheckMapper.selectCmcCheckList(cmcCheck);
    }

    /**
     * 新增cmc项目核算
     * 
     * @param cmcCheck cmc项目核算
     * @return 结果
     */
    @Override
    public int insertCmcCheck(CmcCheck cmcCheck)
    {
        return cmcCheckMapper.insertCmcCheck(cmcCheck);
    }

    /**
     * 修改cmc项目核算
     * 
     * @param cmcCheck cmc项目核算
     * @return 结果
     */
    @Override
    public int updateCmcCheck(CmcCheck cmcCheck)
    {
        return cmcCheckMapper.updateCmcCheck(cmcCheck);
    }

    /**
     * 批量删除cmc项目核算
     * 
     * @param checkIds 需要删除的cmc项目核算主键
     * @return 结果
     */
    @Override
    public int deleteCmcCheckByCheckIds(String[] checkIds)
    {
        return cmcCheckMapper.deleteCmcCheckByCheckIds(checkIds);
    }

    /**
     * 删除cmc项目核算信息
     * 
     * @param checkId cmc项目核算主键
     * @return 结果
     */
    @Override
    public int deleteCmcCheckByCheckId(String checkId)
    {
        return cmcCheckMapper.deleteCmcCheckByCheckId(checkId);
    }
}
